==> qbittorrent_1.3.3.orig.tar.gz: qbittorrent-1.3.3/src/eventmanager.h <==
/*
 * Bittorrent Client using Qt4 and libtorrent.
 * Copyright (C) 2006  Ishan Arora and Christophe Dumez
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 *
 * Contact : chris@qbittorrent.org
 */


#ifndef EVENTMANAGER_H
#define EVENTMANAGER_H

#include "qtorrenthandle.h"
#include <QHash>
#include <QVariant>

struct bittorrent;

class EventManager : public QObject
{
	Q_OBJECT
	private:
		QHash<QString, QVariantMap> event_list;
		bittorrent* BTSession;

	protected:
		void update(QVariantMap event);

	public:
		EventManager(QObject *parent, bittorrent* BTSession);
                QList<QVariantMap> getEventList() const;

	public slots:
		void addedTorrent(QTorrentHandle& h);
		void deletedTorrent(QString hash);
		void modifiedTorrent(QTorrentHandle h);
};

#endif

==> qbittorrent_2.2.11.orig.tar.gz: qbittorrent-2.2.11/src/eventmanager.h <==
/*
 * Bittorrent Client using Qt4 and libtorrent.
 * Copyright (C) 2006  Ishan Arora and Christophe Dumez
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 *
 * Contact : chris@qbittorrent.org
 */


#ifndef EVENTMANAGER_H
#define EVENTMANAGER_H

#include "qtorrenthandle.h"
#include <QHash>
#include <QVariant>

class Bittorrent;

class EventManager : public QObject
{
	Q_OBJECT
	private:
		QHash<QString, QVariantMap> event_list;
                Bittorrent* BTSession;

	protected:
		void update(QVariantMap event);

	public:
                EventManager(QObject *parent, Bittorrent* BTSession);
                QList<QVariantMap> getEventList() const;
                QVariantMap getPropGeneralInfo(QString hash) const;
                QList<QVariantMap> getPropTrackersInfo(QString hash) const;
                QList<QVariantMap> getPropFilesInfo(QString hash) const;
                QVariantMap getGlobalPreferences() const;
                void setGlobalPreferences(QVariantMap m) const;

	public slots:
		void addedTorrent(QTorrentHandle& h);
		void deletedTorrent(QString hash);
		void modifiedTorrent(QTorrentHandle h);
};

#endif
